"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateUniversalConnectionsConfig = void 0;
const universal_1 = require("../../../common/config/universal");
const validateUniversalConnectionsConfig = (checkOptions, config) => {
    if (!config.connections) {
        return {
            id: checkOptions.id,
            name: checkOptions.name,
            status: 'error',
            output: `Missing connections in config`,
        };
    }
    for (const key in config.connections) {
        const currentConnection = (0, universal_1.getConfigForIdentifier)(config.connections[key].identifier, config);
        if (!currentConnection || !currentConnection.type) {
            return {
                id: checkOptions.id,
                name: checkOptions.name,
                status: 'error',
                output: `Missing type in connection ${key} is unsupported`,
            };
        }
        if (!config.supportedBrokerTypes.includes(currentConnection.type)) {
            return {
                id: checkOptions.id,
                name: checkOptions.name,
                status: 'error',
                output: `${currentConnection.type} type in connection ${key} is unsupported`,
            };
        }
        // Check all required elements are there
        for (const requiredKey in config.brokerClientConfiguration[currentConnection.type].required) {
            if (requiredKey != 'type' &&
                !Object.keys(currentConnection).includes(requiredKey)) {
                return {
                    id: checkOptions.id,
                    name: checkOptions.name,
                    status: 'error',
                    output: `Missing ${requiredKey} required in connection ${key}`,
                };
            }
        }
    }
    return {
        id: checkOptions.id,
        name: checkOptions.name,
        status: 'passing',
        output: 'connections config check: ok',
    };
};
exports.validateUniversalConnectionsConfig = validateUniversalConnectionsConfig;
//# sourceMappingURL=universalConnectionConfigCheck.js.map