"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processStartUpHooks = void 0;
const dispatcher_1 = require("../../dispatcher");
const logger_1 = require("../../../logs/logger");
const checks_1 = require("../../checks");
const scm_1 = require("../../scm");
const processStartUpHooks = async (clientOpts, brokerClientId) => {
    var _a, _b, _c, _d, _e, _f;
    try {
        clientOpts.config.API_BASE_URL =
            (_d = (_b = (_a = clientOpts.config.BROKER_DISPATCHER_BASE_URL) !== null && _a !== void 0 ? _a : clientOpts.config.API_BASE_URL) !== null && _b !== void 0 ? _b : (_c = clientOpts.config.BROKER_SERVER_URL) === null || _c === void 0 ? void 0 : _c.replace('//broker.', '//api.').replace('//broker2.', '//api.')) !== null && _d !== void 0 ? _d : 'https://api.snyk.io';
        if (!clientOpts.config.brokerToken &&
            !clientOpts.config.universalBrokerEnabled) {
            const brokerToken = clientOpts.config.brokerToken;
            // null, undefined, empty, etc.
            logger_1.log.error({ brokerToken }, '[MISSING_BROKER_TOKEN] BROKER_TOKEN is required to successfully identify itself to the server');
            const error = new ReferenceError('BROKER_TOKEN is required to successfully identify itself to the server');
            error['code'] = 'MISSING_BROKER_TOKEN';
            throw error;
        }
        if (!clientOpts.config.brokerServerUrl) {
            const brokerServerUrl = clientOpts.config.brokerServerUrl;
            // null, undefined, empty, etc.
            logger_1.log.error({ brokerServerUrl }, '[MISSING_BROKER_SERVER_URL] BROKER_SERVER_URL is required to connect to the broker server');
            const error = new ReferenceError('BROKER_SERVER_URL is required to connect to the broker server');
            error['code'] = 'MISSING_BROKER_SERVER_URL';
            throw error;
        }
        // if (!clientOpts.config.BROKER_CLIENT_URL) {
        //   const proto =
        //     !clientOpts.config.key && !clientOpts.config.cert ? 'http' : 'https';
        //   clientOpts.config.BROKER_CLIENT_URL = `${proto}://localhost:${clientOpts.port}`;
        // }
        let preflightCheckResults = [];
        if ((0, checks_1.preflightChecksEnabled)(clientOpts.config)) {
            // wrap preflight checks execution into try-catch, so the broker client
            // will start anyway
            try {
                preflightCheckResults = await (0, checks_1.executePreflightChecks)(clientOpts.config);
            }
            catch (error) {
                logger_1.log.error({ error }, 'failed to execute preflight checks');
            }
        }
        let serverId;
        if ((0, dispatcher_1.highAvailabilityModeEnabled)(clientOpts.config)) {
            if (clientOpts.config.universalBrokerEnabled) {
                for (const key in clientOpts.config.connections) {
                    serverId = await (0, dispatcher_1.getServerId)(clientOpts.config, clientOpts.config.connections[key].identifier, brokerClientId);
                    if (serverId === null) {
                        logger_1.log.warn({}, 'could not receive server id from Broker Dispatcher');
                        serverId = '';
                    }
                    else {
                        logger_1.log.info({ serverId }, 'received server id');
                        clientOpts.config.connections[key].serverId = serverId;
                    }
                }
            }
            else {
                serverId = await (0, dispatcher_1.getServerId)(clientOpts.config, clientOpts.config.brokerToken, brokerClientId);
                if (serverId === null) {
                    logger_1.log.warn({}, 'could not receive server id from Broker Dispatcher');
                    serverId = '';
                }
                else {
                    logger_1.log.info({ serverId }, 'received server id');
                    clientOpts.config.serverId = serverId;
                }
            }
        }
        if ((0, scm_1.commitSigningEnabled)(clientOpts.config)) {
            const commitSigningRules = (0, scm_1.commitSigningFilterRules)();
            if (clientOpts['universalBrokerEnabled']) {
                (_e = clientOpts.filters['github'].private) === null || _e === void 0 ? void 0 : _e.push(...commitSigningRules);
                (_f = clientOpts.filters['github-enterprise'].github.private) === null || _f === void 0 ? void 0 : _f.push(...commitSigningRules);
            }
            else {
                if (clientOpts.filters instanceof Map) {
                    logger_1.log.error({ clientOpts }, 'Error pushing commit signing rules, unexpected filters type');
                    throw new Error('Error pushing commit signing rules, unexpected filters type');
                }
                else {
                    clientOpts.filters.private.push(...commitSigningRules);
                }
            }
            logger_1.log.info({ enabled: true, rulesCount: commitSigningRules.length }, 'loading commit signing rules');
        }
        if (clientOpts.config.INSECURE_DOWNSTREAM) {
            logger_1.log.warn({}, 'Caution! Running in insecure downstream mode, making downstream calls over http, data is not encrypted');
        }
        return {
            preflightCheckResults: preflightCheckResults.length
                ? preflightCheckResults
                : undefined,
        };
    }
    catch (error) {
        logger_1.log.error({ error }, 'Error processing startup hooks');
        throw error;
    }
};
exports.processStartUpHooks = processStartUpHooks;
//# sourceMappingURL=processHooks.js.map