"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.healthCheckHandler = void 0;
const version_1 = __importDefault(require("../../common/utils/version"));
const token_1 = require("../../common/utils/token");
const socketHelpers_1 = require("../utils/socketHelpers");
const healthCheckHandler = 
// io is available in res.locals.websocket
(req, res) => {
    var _a, _b;
    const websocketConnsArray = res.locals
        .websocketConnections;
    const data = [];
    const statuses = [];
    for (let i = 0; i < websocketConnsArray.length; i++) {
        const isConnOpen = (0, socketHelpers_1.isWebsocketConnOpen)(websocketConnsArray[i]);
        statuses.push(isConnOpen ? 200 : 500);
        const tunnelData = {
            ok: isConnOpen,
            websocketConnectionOpen: isConnOpen,
            brokerServerUrl: websocketConnsArray[i].url.href,
            version: version_1.default,
            transport: websocketConnsArray[i].socket.transport.name,
        };
        if (websocketConnsArray[i].identifier) {
            tunnelData['identifier'] = (0, token_1.maskToken)((_a = websocketConnsArray[i].identifier) !== null && _a !== void 0 ? _a : '');
            tunnelData['friendlyName'] = (_b = websocketConnsArray[i].friendlyName) !== null && _b !== void 0 ? _b : '';
        }
        data.push(tunnelData);
    }
    // healthcheck state depends on websocket connection status
    // value of primus.Spark.OPEN means the websocket connection is open
    return res
        .status(statuses.some((status) => status == 500) ? 500 : 200)
        .json(data.length == 1 ? data[0] : data); // So we don't break current
};
exports.healthCheckHandler = healthCheckHandler;
//# sourceMappingURL=healthcheckHandler.js.map