"use strict";
// import '../common/http/patch-https-request-for-proxying';
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createWebSocket = exports.createWebSockets = void 0;
const primus_1 = __importDefault(require("primus"));
const logger_1 = require("../logs/logger");
const primus_emitter_1 = __importDefault(require("primus-emitter"));
const reconnectHandler_1 = require("./socketHandlers/reconnectHandler");
const identifyHandler_1 = require("./socketHandlers/identifyHandler");
const errorHandler_1 = require("./socketHandlers/errorHandler");
const openHandler_1 = require("./socketHandlers/openHandler");
const closeHandler_1 = require("./socketHandlers/closeHandler");
const requestHandler_1 = require("./socketHandlers/requestHandler");
const chunkHandler_1 = require("./socketHandlers/chunkHandler");
const init_1 = require("./socketHandlers/init");
const integrations_1 = require("./utils/integrations");
const createWebSockets = (clientOpts, globalIdentifyingMetadata) => {
    var _a;
    const integrationsKeys = clientOpts.config.connections
        ? Object.keys(clientOpts.config.connections)
        : [];
    const websocketConnections = [];
    for (let i = 0; i < integrationsKeys.length; i++) {
        const socketIdentifyingMetadata = Object.assign({}, globalIdentifyingMetadata);
        socketIdentifyingMetadata.friendlyName = integrationsKeys[i];
        socketIdentifyingMetadata.identifier =
            clientOpts.config.connections[`${integrationsKeys[i]}`]['identifier'];
        const integrationType = clientOpts.config.connections[`${integrationsKeys[i]}`].type;
        // This type is different for broker, ECR/ACR/DockeHub/etc are all container-registry-agent type for broker
        socketIdentifyingMetadata.supportedIntegrationType =
            (0, integrations_1.translateIntegrationTypeToBrokerIntegrationType)(integrationType);
        socketIdentifyingMetadata.serverId =
            (_a = clientOpts.config.connections[`${integrationsKeys[i]}`].serverId) !== null && _a !== void 0 ? _a : '';
        websocketConnections.push((0, exports.createWebSocket)(clientOpts, socketIdentifyingMetadata));
    }
    return websocketConnections;
};
exports.createWebSockets = createWebSockets;
const createWebSocket = (clientOpts, identifyingMetadata) => {
    var _a;
    const localClientOps = Object.assign({}, clientOpts);
    const Socket = primus_1.default.createSocket({
        transformer: 'engine.io',
        parser: 'EJSON',
        plugin: {
            emitter: primus_emitter_1.default,
        },
        pathname: clientOpts.config.universalBrokerEnabled
            ? `/primus/${identifyingMetadata.identifier}`
            : `/primus/${localClientOps.config.brokerToken}`,
    });
    const urlWithServerId = new URL(localClientOps.config.brokerServerUrl);
    const serverId = (_a = localClientOps.config.serverId) !== null && _a !== void 0 ? _a : identifyingMetadata.serverId;
    if (serverId && serverId > -1) {
        urlWithServerId.searchParams.append('server_id', serverId);
    }
    localClientOps.config.brokerServerUrlForSocket = urlWithServerId.toString();
    // Will exponentially back-off from 0.5 seconds to a maximum of 20 minutes
    // Retry for a total period of around 4.5 hours
    const websocket = new Socket(localClientOps.config.brokerServerUrlForSocket, {
        reconnect: {
            factor: 1.5,
            retries: 30,
            max: 20 * 60 * 1000,
        },
        ping: parseInt(localClientOps.config.socketPingInterval) || 25000,
        pong: parseInt(localClientOps.config.socketPongTimeout) || 10000,
        timeout: parseInt(localClientOps.config.socketConnectTimeout) || 10000,
    });
    websocket.socketVersion = 1;
    websocket.socketType = 'client';
    if (localClientOps.config.universalBrokerEnabled) {
        websocket.identifier = identifyingMetadata.identifier;
        websocket.supportedIntegrationType =
            identifyingMetadata.supportedIntegrationType || '';
        websocket.serverId = serverId || '';
        websocket.friendlyName = identifyingMetadata.friendlyName || '';
    }
    logger_1.log.info({
        url: localClientOps.config.brokerServerUrlForSocket,
        serverId: serverId,
    }, 'broker client is connecting to broker server');
    (0, init_1.initializeSocketHandlers)(websocket, localClientOps);
    // Websocket events
    websocket.on('identify', (serverData) => (0, identifyHandler_1.identifyHandler)(serverData, websocket));
    websocket.on('reconnect scheduled', reconnectHandler_1.reconnectScheduledHandler);
    websocket.on('reconnect failed', () => (0, reconnectHandler_1.reconnectFailedHandler)(websocket));
    websocket.on('chunk', (0, chunkHandler_1.chunkHandler)(localClientOps.config.universalBrokerEnabled
        ? identifyingMetadata.identifier
        : localClientOps.config.brokerToken));
    // prealably initialized
    websocket.on('request', (0, requestHandler_1.requestHandler)(localClientOps.config.universalBrokerEnabled
        ? identifyingMetadata.identifier
        : localClientOps.config.brokerToken));
    websocket.on('error', errorHandler_1.errorHandler);
    websocket.on('open', () => (0, openHandler_1.openHandler)(websocket, localClientOps, identifyingMetadata));
    websocket.on('close', () => (0, closeHandler_1.closeHandler)(localClientOps, identifyingMetadata));
    // only required if we're manually opening the connection
    // websocket.open();
    return websocket;
};
exports.createWebSocket = createWebSocket;
//# sourceMappingURL=socket.js.map