"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateConnection = void 0;
const request_1 = require("../../common/http/request");
const version_1 = __importDefault(require("../../common/utils/version"));
const logger_1 = require("../../logs/logger");
const validateConnection = async (config) => {
    var _a, _b;
    let passing = false;
    const data = [];
    for (let i = 0; i < config.validations.length; i++) {
        const validation = (_a = config.validations[i]) !== null && _a !== void 0 ? _a : {};
        const method = (_b = validation === null || validation === void 0 ? void 0 : validation.method) !== null && _b !== void 0 ? _b : 'GET';
        const { auth, url } = validation;
        const headers = {};
        headers['user-agent'] = `Snyk Broker client ${version_1.default}`;
        switch (auth === null || auth === void 0 ? void 0 : auth.type) {
            case 'basic':
                headers['Authorization'] = `Basic ${Buffer.from(`${auth.username}:${auth.password}`).toString('base64')}`;
                break;
            case 'header':
                headers['Authorization'] = `${auth.value}`;
                break;
            default:
                logger_1.log.warn({ validation }, 'No auth validation');
        }
        const request = {
            method: method,
            url: url,
            headers: headers,
        };
        if (validation.body) {
            request.body = validation.body;
        }
        try {
            const response = await (0, request_1.makeSingleRawRequestToDownstream)(request);
            if (response && response.statusCode) {
                passing =
                    response.statusCode < 300 && response.statusCode > 200 ? true : false;
            }
            data.push({
                url: url,
                data: response.body,
                statusCode: response.statusCode,
            });
        }
        catch (err) {
            data.push({ url: url, data: err });
        }
    }
    return { passing, data };
};
exports.validateConnection = validateConnection;
//# sourceMappingURL=connectionValidation.js.map