"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.overloadConfigWithConnectionSpecificConfig = exports.getConfigForIdentifier = exports.getValidationConfigForType = exports.getConfigForConnection = exports.getConfigForConnectionsFromConfig = exports.getConfigForConnections = exports.getConfigForType = void 0;
const logger_1 = require("../../logs/logger");
const config_1 = require("./config");
const getConfigForType = (type) => {
    var _a;
    const config = (0, config_1.getConfig)();
    return {
        ...config.brokerClientConfiguration.common.default,
        ...config.brokerClientConfiguration.common.required,
        ...(_a = config.brokerClientConfiguration[`${type}`]) === null || _a === void 0 ? void 0 : _a.default,
        // ...config.brokerClientConfiguration[`${type}`].required,
    };
};
exports.getConfigForType = getConfigForType;
const getConfigForConnections = () => {
    const config = (0, config_1.getConfig)();
    return (0, exports.getConfigForConnectionsFromConfig)(config);
};
exports.getConfigForConnections = getConfigForConnections;
const getConfigForConnectionsFromConfig = (config) => {
    const connectionsConfig = new Map();
    for (const key in config.connections) {
        connectionsConfig.set(key, (0, exports.getConfigForConnection)(key, config));
    }
    return connectionsConfig;
};
exports.getConfigForConnectionsFromConfig = getConfigForConnectionsFromConfig;
const getConfigForConnection = (key, config) => {
    return {
        ...(0, exports.getConfigForType)(config.connections[key].type),
        ...config.connections[key],
        ...(0, exports.getValidationConfigForType)(config.connections[key].type),
    };
};
exports.getConfigForConnection = getConfigForConnection;
const getValidationConfigForType = (type) => {
    const config = (0, config_1.getConfig)();
    return {
        validations: config.brokerClientConfiguration[`${type}`].validations,
    };
};
exports.getValidationConfigForType = getValidationConfigForType;
const getConfigForIdentifier = (identifier, config) => {
    const connection = findConnectionWithIdentifier(config.connections, identifier);
    const connectionKey = (connection === null || connection === void 0 ? void 0 : connection.key) || undefined;
    const connectionType = (connection === null || connection === void 0 ? void 0 : connection.value.type) || undefined;
    if (!connectionType) {
        logger_1.log.error({ integrations: config.integrations }, `Unable to find configuration type for ${identifier}. Please review config.`);
        // throw new Error(
        //   `Unable to find configuration type for ${identifier}. Please review config.`,
        // );
    }
    if (!connectionKey) {
        logger_1.log.error({ integrations: config.integrations }, `Unable to find configuration type for ${identifier}. Please review config.`);
        // throw new Error(
        //   `Unable to find configuration type for ${identifier}. Please review config.`,
        // );
    }
    const configToOverload = {
        ...(connectionType ? (0, exports.getConfigForType)(connectionType) : {}),
        ...(connectionKey ? config.connections[connectionKey] : {}),
    };
    const configOverloaded = (0, config_1.expandPlaceholderValuesInFlatList)(configToOverload, configToOverload);
    return configOverloaded;
};
exports.getConfigForIdentifier = getConfigForIdentifier;
const overloadConfigWithConnectionSpecificConfig = (connectionIdentifier, localConfig) => {
    const config = (0, config_1.getConfig)();
    let overloadedConfig = Object.assign({}, {
        ...localConfig,
        ...(0, exports.getConfigForIdentifier)(connectionIdentifier, config),
    });
    overloadedConfig = (0, config_1.expandPlaceholderValuesInFlatList)(overloadedConfig, overloadedConfig);
    return overloadedConfig;
};
exports.overloadConfigWithConnectionSpecificConfig = overloadConfigWithConnectionSpecificConfig;
const findConnectionWithIdentifier = (connections, identifier) => {
    if (!connections) {
        const refError = new ReferenceError('Error Finding connections configuration');
        refError['code'] = 'UNEXPECTED_INVALID_CONNECTIONS_CONFIG';
        throw refError;
    }
    for (const key of Object.keys(connections)) {
        if (connections[key].identifier === identifier) {
            return { key, value: connections[key] };
        }
    }
};
//# sourceMappingURL=universal.js.map