"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.bindSocketToWebserver = exports.getSocketConnections = void 0;
const primus_1 = __importDefault(require("primus"));
const primus_emitter_1 = __importDefault(require("primus-emitter"));
const errorHandler_1 = require("./socketHandlers/errorHandler");
const connectionHandler_1 = require("./socketHandlers/connectionHandler");
const initHandlers_1 = require("./socketHandlers/initHandlers");
const socketConnections = new Map();
const getSocketConnections = () => {
    return socketConnections;
};
exports.getSocketConnections = getSocketConnections;
const socket = ({ server, loadedServerOpts }) => {
    const ioConfig = {
        transformer: 'engine.io',
        parser: 'EJSON',
        maxLength: parseInt(loadedServerOpts.config.socketMaxResponseLength) || 22020096,
        transport: {
            allowEIO3: true,
            pingInterval: parseInt(loadedServerOpts.config.socketPingInterval) || 25000,
            pingTimeout: parseInt(loadedServerOpts.config.socketPingTimeout) || 20000,
        },
        compression: Boolean(loadedServerOpts.config.socketUseCompression) || false,
    };
    const websocket = new primus_1.default(server, ioConfig);
    websocket.socketType = 'server';
    websocket.socketVersion = 1;
    websocket.plugin('emitter', primus_emitter_1.default);
    (0, initHandlers_1.initConnectionHandler)(loadedServerOpts, websocket);
    websocket.on('error', errorHandler_1.handleIoError);
    websocket.on('connection', connectionHandler_1.handleSocketConnection);
    return { websocket };
};
const bindSocketToWebserver = (server, loadedServerOpts) => {
    // bind the socket server to the web server
    return socket({
        server,
        loadedServerOpts,
    });
};
exports.bindSocketToWebserver = bindSocketToWebserver;
//# sourceMappingURL=socket.js.map